<div align="center">

# 😵🦜 dead-parrot
## Framework for Scalable AI Assistants

</div>

**dead-parrot** is a Python package authored by Lucas Konstantin Bärenfänger ([@pygumby](https://github.com/pygumby)) in the context of his thesis for the master's program "Data Analytics & Management" at Frankfurt School of Finance & Management.

----

## Usage

Please refer to the self-contained usage examples provided in the [demos](demos/) folder.

## Development

- Install dependencies: `uv sync`
- Type-check: `uv run mypy .`
- Lint: `uv run ruff check . --fix`
- Format: `uv run ruff format .`

## License

[MIT License](LICENSE)
